'''
Copyright (C) 2016 Andreas Esau
andreasesau@gmail.com

Created by Andreas Esau

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

bl_info = {
    "name": "Driver to Bone Constraint",
    "description": "This Operator lets you create a shape driver constraint to a bone with one single dialog operator. Quick and easy.",
    "author": "Andreas Esau",
    "version": (1, 3,0,"Alpha"),
    "blender": (2, 80, 0),
    "location": "Operator Search -> Driver Constraint",
    "warning": "This addon is still in development.",
    "wiki_url": "",
    "category": "Rigging" }


import bpy

import os
import re
from .constraint_operator import *

import traceback

def add_to_specials(self,context):
    if len(bpy.context.selected_objects) > 0:
        self.layout.operator_context = "INVOKE_DEFAULT"
        self.layout.separator()
        op = self.layout.operator("object.create_driver_constraint",text="Driver Constraint",icon="DRIVER")
        op.mode = "DRIVER"
        if context.active_object.type == "ARMATURE" and len(context.selected_pose_bones) > 1:
            op = self.layout.operator("object.create_driver_constraint",text="Action Constraint",icon="ACTION")
            op.mode = "ACTION"
        
def add_pose_tools(self,context):
    if len(bpy.context.selected_objects) > 0:
        self.layout.operator_context = "INVOKE_DEFAULT"
        self.layout.separator()
        self.layout.label("Driver Tools:")
        op = self.layout.operator("object.create_driver_constraint",text="Driver Constraint",icon="DRIVER")
        op.mode = "DRIVER"
        if context.active_object != None and context.active_object.type == "ARMATURE" and len(context.selected_pose_bones) > 1:
            op = self.layout.operator("object.create_driver_constraint",text="Action Constraint",icon="ACTION")
            op.mode = "ACTION"



list_class ={
    CreateDriverConstraint,
    }         

def register():
    try: 
         for C in list_class:
            bpy.utils.register_class(C)
    except: traceback.print_exc()
    
    bpy.types.VIEW3D_MT_pose_context_menu.append(add_to_specials)
    bpy.types.VIEW3D_MT_object_context_menu.append(add_to_specials)
    bpy.types.VIEW3D_PT_tools_posemode_options.append(add_pose_tools) 
    bpy.types.VIEW3D_PT_tools_object_options.append(add_pose_tools) 
    

def unregister():
    try: 
         for C in list_class:
            bpy.utils.unregister_class(C)
    except: traceback.print_exc()
    
    bpy.types.VIEW3D_MT_pose_context_menu.remove(add_to_specials)
    bpy.types.VIEW3D_MT_object_context_menu.remove(add_to_specials)
    bpy.types.VIEW3D_PT_tools_posemode_options.remove(add_pose_tools) 
    bpy.types.VIEW3D_PT_tools_object_options.remove(add_pose_tools) 
    